Module: Pipekit

Includes:
Configurable
Defined in:
lib/pipekit.rb,
lib/pipekit/deal.rb,
lib/pipekit/note.rb,
lib/pipekit/person.rb,
lib/pipekit/request.rb,
lib/pipekit/version.rb,
lib/pipekit/repository.rb,
lib/pipekit/person_field.rb

Defined Under Namespace

Modules: Repository Classes: Deal, Note, Person, PersonField, Request

Constant Summary collapse

ConfigNotSetError =
Class.new(Exception)
VERSION =
"0.2.0"

Class Attribute Summary collapse

Class Method Summary collapse

Methods included from Configurable

#config, included

Class Attribute Details

.config_file_pathObject



22
23
24
# File 'lib/pipekit.rb', line 22

def config_file_path
  @config_file_path || raise_config_error
end

Class Method Details

.raise_config_errorObject

Raises:



26
27
28
# File 'lib/pipekit.rb', line 26

def raise_config_error
  raise ConfigNotSetError, "You need to create a yaml file with your Pipedrive config and set the path to the file using `Pipedrive.config_file_path = 'path/to/file.yml'`"
end