Method: Pipekit::Request#get

Defined in:
lib/pipekit/request.rb

#get(id = "", query = {}) ⇒ Object

Public: Pipedrive GET API call - does a GET request to the Pipedrive API based on the resource passed in the initialiser

id - If the resource being searched for has an id query - An optional query string start - The offset with which to start the query

As long as “request_all_pages” is not set to false in the config this will recursively call #get until all the pages of the request have been fetched from pipedrive Pipedrive until everything available has been received



54
55
56
57
# File 'lib/pipekit/request.rb', line 54

def get(id = "", query = {})
  uri = uri(id)
  _get(uri, query, get_request(uri, query))
end